.. _django_request_signer:

This branch is used for Django versions >= 1.7.
To use this branch, pip install >= 1.0

*********************
Django Request Signer
*********************

for documentation, please `read the docs <http://readthedocs.org/docs/django-request-signer/en/latest/index.html>`_
